Reference — Django AlphaFilter 0.6 documentation

Django AlphaFilter 0.6 documentation

# Reference

- Table of Contents
- index
  next
  previous

- Main Page

- Installation
- Getting Started
- The Default Alphabet
- The qs_alphabet_filter Template Tag
- Reference
  - Settings

Enter search terms or a module, class or function name.

# Reference

- Settings
  - DEFAULT_ALPHABET
  - ALPHAFILTER_ADMIN_FIELDS

© Copyright 2010, Corey Oordt. Created using Sphinx 1.1.3.

Reference